@@ -16,6 +16,8 @@ configured settings or falls back on defaults
 from django.conf import settings
 from django.test.signals import setting_changed
 from django.dispatch import receiver
+from django.utils.translation import gettext_lazy as _
+from importlib import import_module
 
 DEFAULTS = {
     "EMAIL_TEMPLATES": {
@@ -35,7 +37,34 @@ DEFAULTS = {
             "BODY_HTML": "ai_kit_auth/reset_password_body.html",
         },
     },
+    "ADMIN_FIELDSETS": (
+        (None, {"fields": ("username", "email", "password")}),
+        (_("Personal info"), {"fields": ("first_name", "last_name")}),
+        (
+            _("Permissions"),
+            {
+                "fields": (
+                    "is_active",
+                    "is_staff",
+                    "is_superuser",
+                    "groups",
+                    "user_permissions",
+                ),
+            },
+        ),
+        (_("Important dates"), {"fields": ("last_login", "date_joined")}),
+    ),
+    "ADMIN_ADD_FIELDSETS": (
+        (
+            None,
+            {
+                "classes": ("wide",),
+                "fields": ("username", "email", "password1", "password2"),
+            },
+        ),
+    ),
     "USERNAME_REQUIRED": False,
+    "USER_SERIALIZER": "ai_kit_auth.serializers.UserSerializer",
     "FRONTEND": {
         "URL": "",
         "ACTIVATION_ROUTE": "/auth/activation/",
@@ -81,6 +110,9 @@ class APISettings:
         }
 
     def __getattr__(self, attr):
+        if attr == "USER_SERIALIZER" and type(self._settings[attr]) == str:
+            module, name = self._settings[attr].rsplit(".", 1)
+            self._settings[attr] = getattr(import_module(module), name)
         return self._settings[attr]
 
     @classmethod
